#!/bin/sh
# -*- mode: landisk-sh; coding: utf-8; -*-
#
# script_full.sh: System initialization script for HDL-X series.
# Copyright (C) 2013-2016 I-O DATA DEVICE, INC.  All rights reserved.
#

DEBUG=
#DEBUG=1

ZEROCLEAR=1

DEV_LED_GOOD="/dev/led_good" 	
DEV_LED_ERROR="/dev/led_error"


###############################################################################
# STATUS LED を赤点滅にする
###############################################################################
__set_status_led_red_blink()
{
	if [ ! -e "${DEV_LED_GOOD}" ]; then
		return 1
	fi
	if [ ! -e "${DEV_LED_ERROR}" ]; then
		return 1
	fi

	echo 0 > "${DEV_LED_GOOD}"
	echo 2 > "${DEV_LED_ERROR}"

	return 0
}


###############################################################################
# エラー表示する
# 入力: 引数1=表示メッセージ
###############################################################################
__initialization_error()
{
	local msg="${1}"

	# ステータス赤点滅
	__set_status_led_red_blink
	echo "###### ERROR ######"
	echo "${msg}"

	# スクリプトを抜けて通常起動の流れへ
	exit 1
}


###############################################################################
# main
###############################################################################

echo "### system initialization start #########################################"

SRCDISK="${1}"

if [ ! -e "${SRCDISK}" ]; then
	# ディスクが存在しない(通常ここにはこない)
	__initialization_error "source disk not found."
fi

if [ ! -e "${SRCDISK}p1" ]; then
	# パーティションが存在しない(通常ここにはこない)
	__initialization_error "source partition not found."
fi

/bin/mount -t vfat -o codepage=932,iocharset=iso8859-1,utf8 \
	"${SRCDISK}p1" \
	"${D_MP_INIT}" \
	1>/dev/null 2>/dev/null
if [ ${?} -ne 0 ]; then
	# マウントできない(通常ここにはこない)
	__initialization_error "failed to mount source."
fi

# 初期化処理
cp -a ${D_INIT_FW}/initialize.sh /
/initialize.sh "${SRCDISK}" "${ZEROCLEAR}"

# 初期化完了
if [ -e "${F_INITIALIZATION}" ]; then
	rm -f "${F_INITIALIZATION}" 1>/dev/null 2>/dev/null
fi

/bin/umount "${D_MP_INIT}" 1>/dev/null 2>/dev/null

if [ "x${DEBUG}" != "x" ]; then
	# デバッグ
	/bin/sh
fi

echo "### system initialization end ###########################################"
