# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

"""Variables for Product wide setting"""

from product_conf import (NET_IF_LIST,)

#
# Device/Volume Information
#

# For network
NET_DEV_LIST = ("netif1", "netif2")
NET_RAW_DEV_LIST = ("eth0", "eth1")
NET_IF_TO_DEV = dict(zip(NET_IF_LIST, NET_DEV_LIST))
NET_DEV_TO_IF = dict(zip(NET_IF_TO_DEV.values(), NET_IF_TO_DEV.keys()))
NET_DEV_TO_RAW_DEV = dict(zip(NET_DEV_LIST, NET_RAW_DEV_LIST))


# For LCM
LCM_SUPPORTED = False


# For storage
RAID_DEV_LIST = ("md2", "md5", "md6", "md13")
SYSTEM_RAID_DEV_LIST = ("md2", "md5")
INTERNAL_RAID_DEV_LIST = ("md6",)
SATA_HDD_DEV_LIST = ("satad1", "satad2",)

ESATA_HDD_DEV_LIST = ()
USB_HDD_DEV_LIST = ("usbd1", "usbd2", "usbd3", "usbd4")
USB_UPS_DEV_LIST = ("usbups1", "usbups2", "usbups3", "usbups4")
SERIAL_UPS_DEV_LIST = ("serialups1",)

UPS_VENDOR_APC = "apc"
UPS_VENDOR_OMRON = "omron"
UPS_VENDOR_FUJI = "fuji"
UPS_VENDOR_SUFFIX_LIST = (UPS_VENDOR_APC, UPS_VENDOR_OMRON, UPS_VENDOR_FUJI)
UPS_SERIAL_TYPE_SUFFIX_LIST = ("smart",)
USB_LP_DEV_LIST = ("usblp1", "usblp2", "usblp3", "usblp4")
LOCKKEY_VOL_LIST = ("usb1",)
MIRRORING_VOL_LIST = ("usb3",)

REAL_USB_UPS_LIST = \
    tuple(".".join(name_suf) for name_suf in \
        zip(sorted(USB_UPS_DEV_LIST * len(UPS_VENDOR_SUFFIX_LIST)),
            UPS_VENDOR_SUFFIX_LIST * len(USB_UPS_DEV_LIST)))
REAL_SERIAL_UPS_LIST = \
    tuple(".".join(name_suf) for name_suf in \
        zip(SERIAL_UPS_DEV_LIST * len(UPS_SERIAL_TYPE_SUFFIX_LIST),
            tuple(".".join(suffix) for suffix in \
                zip(UPS_SERIAL_TYPE_SUFFIX_LIST,
                    [UPS_VENDOR_APC] * len(UPS_SERIAL_TYPE_SUFFIX_LIST)))))
REAL_UPS_DEV_LIST = REAL_USB_UPS_LIST + REAL_SERIAL_UPS_LIST

PORT_IF_LIST = ("sata", "usb", "serial")
SATA_PORT_NO_LIST = ("1", "2")
ESATA_PORT_NO_LIST = ()
USB_PORT_NO_LIST = ("1", "2", "3", "4")
SERIAL_PORT_NO_LIST = ("1",)

PORT_IF_TO_NO_LIST = dict(zip(PORT_IF_LIST,
                                (SATA_PORT_NO_LIST, USB_PORT_NO_LIST,
                                    SERIAL_PORT_NO_LIST)))

FAN_NO_LIST = ("2",)

HDD_DEV_LIST = SATA_HDD_DEV_LIST + USB_HDD_DEV_LIST + ESATA_HDD_DEV_LIST
UPS_DEV_LIST = USB_UPS_DEV_LIST + SERIAL_UPS_DEV_LIST
LP_DEV_LIST = USB_LP_DEV_LIST
ALL_DEV_LIST = HDD_DEV_LIST + ESATA_HDD_DEV_LIST + UPS_DEV_LIST + LP_DEV_LIST

DEV_TO_PORT_IF = dict(zip(SATA_HDD_DEV_LIST,
                            ("sata",) * len(SATA_HDD_DEV_LIST)) +
                    zip(USB_HDD_DEV_LIST,
                            ("usb",) * len(USB_HDD_DEV_LIST)) +
                    zip(UPS_DEV_LIST,
                            ("usb",) * len(USB_HDD_DEV_LIST) + ("serial",)) +
                    zip(USB_LP_DEV_LIST,
                            ("usb",) * len(USB_HDD_DEV_LIST)))

DEV_TO_PORT_NO = dict(zip(SATA_HDD_DEV_LIST, SATA_PORT_NO_LIST) +
                    zip(USB_HDD_DEV_LIST, USB_PORT_NO_LIST) +
                    zip(UPS_DEV_LIST, USB_PORT_NO_LIST + SERIAL_PORT_NO_LIST) +
                    zip(USB_LP_DEV_LIST, USB_PORT_NO_LIST))

PORT_IF_TO_DEVS = dict(zip(PORT_IF_LIST,
                        (dict(zip(SATA_PORT_NO_LIST, zip(SATA_HDD_DEV_LIST))),
                            dict(zip(USB_PORT_NO_LIST,
                                zip(USB_HDD_DEV_LIST, USB_UPS_DEV_LIST,
                                    USB_LP_DEV_LIST))),
                            dict(zip(SERIAL_PORT_NO_LIST,
                                zip(SERIAL_UPS_DEV_LIST))))))

DEV_TO_ENC_DEV = {
                "sataraidd1": "sataraidd1_enc",
                "usbd1": "usbd1_enc",
                "usbd2": "usbd2_enc",
                "usbd3": "usbd3_enc",
                "usbd4": "usbd4_enc",
                "satad1p3": "satad1p3_enc",
                "satad2p3": "satad2p3_enc",
                "satad3p3": "satad3p3_enc",
                "satad4p3": "satad4p3_enc",
                "satad5p3": "satad5p3_enc",
                "satad6p3": "satad6p3_enc",
                "satad1p6": "satad1_vfs_enc",
                "satad2p6": "satad2_vfs_enc",
                "satad3p6": "satad3_vfs_enc",
                "satad4p6": "satad4_vfs_enc",
                "satad5p6": "satad5_vfs_enc",
                "satad6p6": "satad6_vfs_enc",
                "usbd3p3": "usbd3p3_enc",
                "usbd3p6": "usbd3_enc",
                "usbd4p6": "usbd4_enc",
    }

RAID_MODE_TO_REAL_RAID_MODE = {
                "vfsext"  : "vfsext",
                "vfsext_6": "vfsext",
                "vfsext_4": "vfsext",
                "vfsext_3": "vfsext_3",
                "vfsext_2": "vfsext_2",
                "raid0"   : "raid0",
                "raid0_6" : "raid0",
                "raid0_4" : "raid0",
                "raid0_3" : "raid0",
                "raid0_2" : "raid0",
                "raid1"   : "raid1",
                "raid1_4" : "raid1",
                "raid1_3" : "raid1",
                "raid1_2" : "raid1",
                "raid5"   : "raid5",
                "raid5_6" : "raid5",
                "raid5_4" : "raid5",
                "raid6"   : "raid6",
                "raid6_6" : "raid6",
                "raid6_4" : "raid6",
    }

EXTEND_RAID_MODE_MAP = {
                "vfsext"  : (),
                "raid0"   : (),
                "raid1"   : (),
}

_RAID_MODE_LIST = {
        2: ("vfsext", "raid0", "raid1",),
    }

VOL_INFO = {
        "sataraid1": {
                "dev": "sataraidd1",
                "part_base": "",
                "mode_list": _RAID_MODE_LIST,
                "mnt_point": "/mnt/sataraid1",
                "alt_mnt_point": "/mnt/share/sataraid1",
                "swap_dev_list": {
                        2: tuple([dev + "p3" for dev in SATA_HDD_DEV_LIST]),
                },
                "share_root": "share",
            },
        "usb1": {
                "dev": "usbd1",
                "part_base": "usbd1p",
                "mode_list": (),
                "mnt_point": "/mnt/usb1",
                "alt_mnt_point": "/mnt/share/usb1",
                "share_root": "",
            },
        "usb2": {
                "dev": "usbd2",
                "part_base": "usbd2p",
                "mode_list": (),
                "mnt_point": "/mnt/usb2",
                "alt_mnt_point": "/mnt/share/usb2",
                "share_root": "",
            },
        "usb3": {
                "dev": "usbd3",
                "part_base": "usbd3p",
                "mode_list": (),
                "mnt_point": "/mnt/usb3",
                "alt_mnt_point": "/mnt/share/usb3",
                "swap_dev_list": {
                        2: ("usbd3p3",),
                },
                "share_root": "",
            },
        "usb4": {
                "dev": "usbd4",
                "part_base": "usbd4p",
                "mode_list": (),
                "mnt_point": "/mnt/usb4",
                "alt_mnt_point": "/mnt/share/usb4",
                "share_root": "",
            },
    }

DEV_TO_VOL = {
       "sataraidd1": "sataraid1",
       "usbd1": "usb1",
       "usbd2": "usb2",
       "usbd3": "usb3",
       "usbd4": "usb4",
    }

HDD_DEV_LIST_IN_VOL = {
        2:{
              "sataraid1": SATA_HDD_DEV_LIST + ("usbd3",),
              "usb1": ("usbd1",),
              "usb2": ("usbd2",),
              "usb3": ("usbd3",),
              "usb4": ("usbd4",),
        },
    }

RAID_MODE_INFO = {
        "vfsext": {
                "array_num": 2,
                "is_ext_raid": True,
        },
        "raid0": {
                "array_num": 2,
                "is_ext_raid": False,
        },
        "raid1": {
                "array_num": 2,
                "is_ext_raid": False,
        },
    }

RAID_TO_REAL_NAME = {
        "sataraidd1" : "md13",
    }

REAL_TO_RAID_NAME = \
    dict((real, symbl) for symbl, real in RAID_TO_REAL_NAME.iteritems())

RAID_TO_ELEMENT = {
        2: {
                "sataraidd1" : ("md6", "usbd3p6", "missing"),
                "md2"  : tuple([dev + "p2" for dev in SATA_HDD_DEV_LIST] +
                                ["usbd3p2", "missing"]),
                "md5"  : tuple([dev + "p5" for dev in SATA_HDD_DEV_LIST] +
                                ["usbd3p5", "missing"]),
                "md6"  : tuple([dev + "p6" for dev in SATA_HDD_DEV_LIST]),
        },
    }

RAID_TO_LEVEL = {
        "sataraidd1": "raid1",
        "md2": "raid1",
        "md5": "raid1",
        "md6": "", # RAID mode must be got from other information.
    }

EXT_RAID_TO_ELEMENT = {
        2: {
                "sataraidd1": tuple([dev + "p6" for dev in SATA_HDD_DEV_LIST] +
                                     ["usbd3p6", "usbd4p6"]),
        },
    }

VFSEXT_INFO = {
              "filesystem": "xfs",
    }

EXT_RAID_DEV_INFO = {
    "satad1p6": {
        "mnt_point": "/mnt/vfsext/sata1",
        "mirrset": (1, 1),
        "is_external": False,
        },
    "satad2p6": {
        "mnt_point": "/mnt/vfsext/sata2",
        "mirrset": (1, 2),
        "is_external": False,
        },
    "satad3p6": {
        "mnt_point": "/mnt/vfsext/sata3",
        "mirrset": (2, 1),
        "is_external": False,
        },
    "satad4p6": {
        "mnt_point": "/mnt/vfsext/sata4",
        "mirrset": (2, 2),
        "is_external": False,
        },
    "satad5p6": {
        "mnt_point": "/mnt/vfsext/sata5",
        "mirrset": (3, 1),
        "is_external": False,
        },
    "satad6p6": {
        "mnt_point": "/mnt/vfsext/sata6",
        "mirrset": (3, 2),
        "is_external": False,
        },
    "usbd3p6": {
        "mnt_point": "/mnt/vfsext/usb3",
        "mirrset": (4, 1),
        "is_external": True,
        },
    "usbd4p6": {
        "mnt_point": "/mnt/vfsext/usb4",
        "mirrset": (4, 2),
        "is_external": True,
        },
    }


MOUNT_OPT_INFO = {
        "xfs"  : "defaults,usrquota,grpquota,allocsize=64k",
        "vfat" : "codepage=932,utf8,shortname=winnt,umask=000,uid=nobody,gid=nogroup",
        "ext3" : "relatime",
        "ext4" : "relatime",
        "ntfs-fuse" : "ro,relatime,locale=ja_JP.UTF-8,umask=000",
        "vfsext": "usrquota,grpquota",
    }

SUPPORTED_FSCK_FSYS = ("ext3", "ext4", "xfs",)

SYS_VOL_INFO = {
        "rootfs": {
            "dev": "md2",
            "mnt_point": "/",
        },
        "boot": {
            "devlist": {
                2: tuple([dev + "p1" for dev in SATA_HDD_DEV_LIST]),
            },
            "mnt_point": "/boot",
        }
    }

